/* -*- indent-tabs-mode: t; tab-width: 8; c-basic-offset: 8; -*- */

/**
 * Extra declarations for use with the iso_volume structure.
 */

#ifndef __ISO_VOLUME
#define __ISO_VOLUME

#include "libisofs.h"

/**
 * Fixed-length character data in a volume.
 */
struct iso_volume_cdata {
	char *iso;	/**< D-character version of the data. */
	char *joliet;	/**< Joliet version of the data. */
	int size;	/**< Size in bytes of the data. */
};

/**
 * Volume options.
 */
struct iso_volume_options {
	int iso_level;	/**< Current ISO-level (1 or 2). */
	int rockridge;	/**< Whether Rock Ridge (POSIX) is enabled. */
	int joliet;	/**< Whether Joliet (Unicode) is enabled. */
};

/**
 * Data volume.
 */
struct iso_volume {
	int refcount;					/**< Number of used references to the volume. */

	struct iso_tree_dir *root;			/**< Root of the directory tree for the volume. */

	struct iso_volume_cdata volume_id;		/**< Volume identifier. */
	struct iso_volume_cdata publisher_id;		/**< Volume publisher. */
	struct iso_volume_cdata data_preparer_id;	/**< Volume data preparer. */

	struct iso_volume_options options;		/**< Current volume options. */
};

#endif /* __ISO_VOLUME */
